/* Copyright (c) 2015 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file mqtt_rx.h
 *
 * @brief Internal methods to submit received packet.
 */

#ifndef MQTT_RX_H_
#define MQTT_RX_H_

#include "nordic_common.h"
#include "sdk_common.h"
#include "mqtt.h"
#include "iot_errors.h"
#include "nrf_tls.h"
#include "app_trace.h"


/**@brief Handles MQTT messages received from the peer. For TLS, this routine is evoked to handle
 *        decrypted application data. For TCP, this routine is evoked to handle TCP data.
 *
 * @param[in]    p_client     Identifies the client for which the data was received.
 * @param[in]    p_data       MQTT data received.
 * @param[inout] datalen      Length of data received.
 *
 * @retval NRF_SUCCESS if the procedure is successul, else an error code indicating the reason
 *                     for failure.
 */
uint32_t mqtt_handle_rx_data(mqtt_client_t * p_client, uint8_t * p_data, uint32_t datalen);

#endif // MQTT_RX_H_
