/* Copyright (c) 2016 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file mqtt_transport.c
 *
 * @brief Internal functions to handle transport in MQTT module.
 */


#include "mqtt_transport.h"


/**< Function pointer array for TCP/TLS transport handlers. */
const transport_procedure_t transport_fn[MQTT_TRASNPORT_MAX] =
{
    {
        mqtt_client_tcp_connect,
        mqtt_client_tcp_write,
        mqtt_client_tcp_read,
        mqtt_client_tcp_disconnect
    },
    {
        mqtt_client_tls_connect,
        mqtt_client_tls_write,
        mqtt_client_tls_read,
        mqtt_client_tls_disconnect
    }
};


uint32_t mqtt_transport_connect(mqtt_client_t * p_client)
{
    return transport_fn[p_client->transport_type].connect(p_client);
}


uint32_t mqtt_transport_write(mqtt_client_t * p_client, uint8_t const * p_data, uint32_t datalen)
{
    return transport_fn[p_client->transport_type].write(p_client, p_data, datalen);
}


uint32_t mqtt_transport_read(mqtt_client_t * p_client, uint8_t * p_data, uint32_t datalen)
{
    return transport_fn[p_client->transport_type].read(p_client, p_data, datalen);
}


uint32_t mqtt_transport_disconnect(mqtt_client_t * p_client)
{
    return transport_fn[p_client->transport_type].disconnect(p_client);
}
